@@ -1,5 +1,9 @@
+"""Copyright (C) Nanosurf AG - All Rights Reserved (2021)
+License - MIT"""
+
+
 import time
-from nanosurf.lib.devices import i2c 
+import nanosurf.lib.devices.i2c.bus_master as i2c 
 
 class Chip_24LC32A(i2c.I2CChip):
     """ EEPROM chip"""
