@@ -180,18 +180,17 @@ class _SciLineEditQt(QtWidgets.QLineEdit):
         if (key == Qt.Key_Return) or (key == Qt.Key_Enter):
             super().keyPressEvent(event)
             self._reformat(True)
-        elif (key==Qt.Key_Delete)  or event.matches(QtGui.QKeySequence.Delete):
+        elif (key==Qt.Key_Delete) or event.matches(QtGui.QKeySequence.Delete):
             if not(self._is_cursor_behind_last_digit()):
                 super().keyPressEvent(event)
-                self._handle_selection()
         elif (key == Qt.Key_Escape):
             self._show_value()
             self._reformat(True)
             self.clearFocus()
-        elif (key == Qt.Key_Down):
+        elif (key == Qt.Key_Down) or (key == Qt.Key_PageDown):
             self._decrement()
             self._show_value()     
-        elif (key == Qt.Key_Up):
+        elif (key == Qt.Key_Up) or (key == Qt.Key_PageUp):
             self._increment()
             self._show_value()   
         elif (key == Qt.Key_F):
@@ -218,15 +217,21 @@ class _SciLineEditQt(QtWidgets.QLineEdit):
             self._toggle_auto_prefix_mode()
         elif (key == Qt.Key_A) and ctrl:
             self._toggle_auto_prefix_mode()
-        elif (key == Qt.Key_Backspace) or event.matches(QtGui.QKeySequence.Paste):
+        elif (key == Qt.Key_Backspace) :
             super().keyPressEvent(event)
-            self._handle_selection()
-        elif event.matches(QtGui.QKeySequence.SelectAll) or event.matches(QtGui.QKeySequence.Copy):
+        elif event.matches(QtGui.QKeySequence.SelectAll) or event.matches(QtGui.QKeySequence.Copy) or event.matches(QtGui.QKeySequence.Paste):
             super().keyPressEvent(event)
             self._handle_selection()
         elif (key == Qt.Key_Insert) or (key == Qt.Key_Insert) or (key == Qt.Key_End):
             super().keyPressEvent(event)
             self._handle_selection()
+        elif (key == Qt.Key_Home):
+            self.setCursorPosition(0)
+            super().keyPressEvent(event)
+        elif (key == Qt.Key_End):
+            self.setCursorPosition(len(self.text()))
+            self._limit_cursor_to_last_digi()
+            super().keyPressEvent(event)
         elif (key == Qt.Key_Left):
             if self.text() == self.selectedText():
                 self.setCursorPosition(0)
@@ -251,10 +256,11 @@ class _SciLineEditQt(QtWidgets.QLineEdit):
              (key == Qt.Key_9):
             if len(self.text()) < self._max_characters:
                 super().keyPressEvent(event)
-                self._handle_selection()
         elif (key == Qt.Key_Plus) or \
-             (key == Qt.Key_Minus) or \
-             (key == Qt.Key_Asterisk) or \
+             (key == Qt.Key_Minus):
+            if len(self.text()) < self._max_characters:
+                super().keyPressEvent(event)
+        elif (key == Qt.Key_Asterisk) or \
              (key == Qt.Key_Slash) or \
              (key == Qt.Key_AsciiCircum) or \
              (key == Qt.Key_E) or \
@@ -267,7 +273,8 @@ class _SciLineEditQt(QtWidgets.QLineEdit):
             super().keyPressEvent(event)
             self._handle_selection()
         else:
-            self._handle_selection()
+            if not (ctrl or shift):
+                self._handle_selection()
 
     def wheelEvent(self, event: QtGui.QWheelEvent) -> None:
         """ overwrite handler for wheel event"""
@@ -535,7 +542,7 @@ class _SciLineEditQt(QtWidgets.QLineEdit):
 
 
 class NSFSciEdit(QtWidgets.QWidget):
-    """ Custom Qt Widget to show scientific numbers in a edit with a descriptiv label. """
+    """ Custom Qt Widget to show scientific numbers in a edit with a descriptive label. """
     value_changed_event = Signal(float)
 
     def __init__(self, label_str = "", *args, **kwargs):
