@@ -3,8 +3,6 @@ Copyright (C) Nanosurf AG - All Rights Reserved (2021)
 License - MIT"""
 
 import time
-import enum
-import typing
 from nanosurf.lib.spm import scanhead
 import nanosurf
 from nanosurf.lib.spm.scanhead import motor_control as mc
