@@ -181,7 +181,9 @@ class StudioScriptContext(StudioScriptInterface):
         self._context_id = ScriptContext.Main
         self._lua = lupa.LuaRuntime(unpack_returned_tuples=True)
         self._lua_deser_func = self._lua.eval("function(ser_str) local func_c, _ = load('return '..ser_str); return func_c(); end") 
-
+        self._root_table_name = "root_table_get_result"
+        self._lua_math_type_check_func = self._lua.eval(f"function(var_name) local func_c, _ = load('return tostring(math.type({self._root_table_name}[2][1].' .. var_name .. '))'); return func_c(); end") 
+                
     def connect(self, session: str, context: ScriptContext, host: str = g_default_ip_addr, port: int = g_default_ip_port) -> bool:
         """ Establish a connection to specified session and context.
             
@@ -294,6 +296,32 @@ class StudioScriptContext(StudioScriptInterface):
             print(self._last_error)
         return ok
 
+    def load_studio_root_table(self, lua_str: str) -> Any:
+        res_ok = False
+        res_val: dict = None
+        return_val = self.execute_command(f"return {lua_str}")
+        if return_val is not None:
+            try:
+                self._lua.execute(f"{self._root_table_name} = {return_val}")
+
+                lua_deser_table = self._lua_deser_func(return_val)
+                lua_ok = lua_deser_table[1] == 0
+                res_val = lua_deser_table[2][1]
+                if not lua_ok:
+                    self._last_error = f"Scripting: {str(res_val)}"
+                    res_val = None
+                
+                # re = self._lua_math_type_check_func("test.num_f")
+
+                res_ok = True
+            except lupa._lupa.LuaError as er:
+                self._last_error = f"Lupa Error: {er}:\n{return_val}"
+            except lupa._lupa.LuaSyntaxError:
+                self._last_error = f"Lupa SyntaxError:\n{return_val}"
+            except TypeError:
+                self._last_error = f"Lupa TypeError:\n{return_val}"
+        return res_val
+
     def lua_type(self, obj) -> str:
         """ convenient function to evaluate the type of a result variable. 
             If the obj provided is a lua type, then the type name is returned. Otherwise None.
@@ -301,6 +329,12 @@ class StudioScriptContext(StudioScriptInterface):
         """
         return lupa.lua_type(obj)
 
+    def lua_number_type_str(self, value_name : str) -> str:
+        if "root." in value_name:
+            value_name = value_name.removeprefix("root.")
+        num_type_str = self._lua_math_type_check_func(value_name)
+        return num_type_str
+
     def _process_command(self, cmd_str: str) -> tuple[bool, Any]:
         res_ok = False
         res_val: dict = None
@@ -359,8 +393,8 @@ class StudioScriptContext(StudioScriptInterface):
         return ok
 
     def _init_cmd_tree(self) -> bool:
-        compiler = studio_wrapper.CmdTreeCompiler()
-        root_table = self.get("root", convert_result_to_python_type=False)
+        compiler = studio_wrapper.CmdTreeCompiler(self)
+        root_table = self.load_studio_root_table("root")
         ok = compiler.build_wrapper_class(self._context_id.name.lower(), root_table)
         if ok:
             if self._context_id == ScriptContext.Main:
