@@ -8,7 +8,7 @@ import numpy as np
 import time
 
 import nanosurf
-import nanosurf.lib.spm as spm
+import nanosurf.lib.spm.com_proxy as spm
 
 class _ModulationOutput():
     def __init__(self):
@@ -149,10 +149,10 @@ class _OutPositionX(_ModulationOutput):
         self._scan_x_out = lowlevel.AnalogHiResOut(
                 lowlevel.AnalogHiResOut.Instance.POSITIONX)
         self._old_scan_x_out = self._scan_x_out.input.value
-        self._scan_x_out.input = self._scan_x_out.InputChannels.GenTest_Dynamic
+        self._scan_x_out.input.value = self._scan_x_out.InputChannels.Analyzer2_Reference
 
     def __del__(self):
-        self._scan_x_out.input = self._old_scan_x_out
+        self._scan_x_out.input.value = self._old_scan_x_out
         super().__del__()
 
 
@@ -162,10 +162,10 @@ class _OutPositionY(_ModulationOutput):
         self._scan_y_out = lowlevel.AnalogHiResOut(
                 lowlevel.AnalogHiResOut.Instance.POSITIONY)
         self._old_scan_y_out = self._scan_y_out.input.value
-        self._scan_y_out.input = self._scan_y_out.InputChannels.GenTest_Dynamic
+        self._scan_y_out.input.value = self._scan_y_out.InputChannels.Analyzer2_Reference
 
     def __del__(self):
-        self._scan_y_out.input = self._old_scan_y_out
+        self._scan_y_out.input.value = self._old_scan_y_out
         super().__del__()
 
 
@@ -176,7 +176,7 @@ class _OutPositionZ(_ModulationOutput):
             lowlevel.AnalogHiResOut.Instance.POSITIONZ)
         self._old_posz_input = self._hi_res_pos_out_z.input.value
         self._hi_res_pos_out_z.input.value = (
-                self._hi_res_pos_out_z.InputChannels.GenTest_Dynamic)
+                self._hi_res_pos_out_z.InputChannels.Analyzer2_Reference)
 
     def __del__(self):
         self._hi_res_pos_out_z.input.value = self._old_posz_input
